pub fn align_up_u32(value: u32, align: u32) -> u32Expand description
Round value up to the next multiple of align.
align must be non-zero; when it is, the result is the smallest multiple
of align that is >= value. Returns value unchanged if align == 0.